PyXMake Developer Guide: PyXMake.VTL.stm_make Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Classes
PyXMake.VTL.stm_make Namespace Reference

Start build jobs on the Jenkins Test Server using PyXMake. More...

## Classes
class | _BaseCommandRunner
class | _BaseTest
class | abq_mcodac
class | app_pycodac
class | bundle_pycodac
class | Clean
class | doxy_boxbeam
class | doxy_mcdcore
class | doxy_mcdmapper
class | doxy_mcdpycodac
class | doxy_mcdsubbuck
class | doxy_pyxmake
class | f2py_beos
class | f2py_boxbeam
class | f2py_mcodac
class | InDevelopmentTest
class | java_boxbeam
class | java_mcodac
class | LongTest
class | pylint
class | pyx_app
class | pyx_bundle
class | pyx_custom
class | pyx_doxygen
class | pyx_f2py
class | pyx_fortran
class | pyx_sphinx
class | sphinx_stmlab
class | Test
class | win_boxbeam
class | win_mcodac

## Detailed Description

Start build jobs on the Jenkins Test Server using PyXMake.

    Jenkins Test Server script.

    @note: Start build jobs on the Jenkins Test Server using PyXMake.

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake, PyCODAC

    @change:
          -

    @author:
           - hein_fa                                                 [DLR-FA,STM Braunschweig]
           - garb_ma                                              [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Author
  Falk Heinecke, Marc Garbade

Date
  20.03.2018

Notes/Changes
  - Added documentation // mg 28.06.2018